/**
 * CFFEX Confidential.
 *
 * @Copyright 2018 CFFEX.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the China Copyright Office.
 *
 * Date:   2018-11-12
 */

#ifndef __DS_DEEP_SUPERVISE_DATA_STRUCT_H__
#define __DS_DEEP_SUPERVISE_DATA_STRUCT_H__

#include "DeepSuperviseDataTypes.h"

namespace cffex_deep_supervise {

enum DS_ENCRYPT_TYPE {
    DS_ENCRYPT_RSA_PKCS1_PADDING        = '1',
    DS_ENCRYPT_RSA_PKCS1_OAEP_PADDING   = '2',
    DS_ENCRYPT_RSA_SSLV23_PADDING       = '3',
    DS_ENCRYPT_RSA_NO_PADDING           = '4',
    DS_ENCRYPT_SM2                      = '5',
    DS_ENCRYPT_MD5                      = '6',
    DS_ENCRYPT_SM3                      = '7'
};

//terminal type
enum DS_TERMINAL_TYPE {
    DS_TERMINAL_WINDOWS     = '1', ///Windows
    DS_TERMINAL_LINUX       = '2', ///Linux
    DS_TERMINAL_MACOS       = '3', ///Mac Os
    DS_TERMINAL_IOS         = '4', ///IOS
    DS_TERMINAL_ANDROID     = '5', ///Android
    DS_TERMINAL_OFFLINE     = '6', ///offline
    DS_TERMINAL_WECHAT      = '7'  ///webchat
};

//user type
enum DS_USER_TYPE {
    DS_USER_CLIENT          = '1', ///client
    DS_USER_OPERATOR        = '2'  ///operator
};

//exception flag
enum DS_EXCEPTION_FLAG_TYPE {
    DS_EXCEPTION_FLAG_NORMAL                = '0', ///normal
    DS_EXCEPTION_FLAG_TERMINAL_INFO_NULL    = '1', ///info is null
    DS_EXCEPTION_FLAG_ENCRYPT_KEY_VERSION   = '2', ///source public key version error
    DS_EXCEPTION_FLAG_TERMINAL_DATA         = '3'  ///terminal data error
};

struct CUserCertificateField {
   ///userAppID
   TFfexDsAppIDType                 AppID;
   ///user password
   TFfexDsPasswordType              Password;
   ///encrypt type
   TFfexDsEncryptType               EncryptType;
};

struct CUserCertificateSoRspField {
    ///public key
    TFfexDsPubliKeyType             PublicKey;
    ///public key type
    TFfexDsEncryptType              EncryptType;
    ///user AppID
    TFfexDsAppIDType                AppID;
    ///encrypted password using public key
    TFfexDsPublicEncResultType      EncryptPassword;
    ///Length of EncryptPassword
    TFfexDsIntType                  EncryptPasswordLen;
};

struct CSourcePublicKeyField {
    ///public key
    TFfexDsPubliKeyType             PublicKey;
    ///public key type
    TFfexDsEncryptType              EncryptType;
    ///public version
    TFfexDsPublicKeyVersionType     PublicyKeyVersion;
};

struct CUserCertificateFrontRspField {
    ///user AppID
    TFfexDsAppIDType                AppID;
    ///user public key type
    TFfexDsEncryptType              UserPubKeyType;    
    ///source public key type
    TFfexDsEncryptType              SourcePubKeyType;    
    ///source public key version
    TFfexDsPublicKeyVersionType     SourcePubKeyVersion;
    ///digest of the encrypted source public key using user public key
    TFfexDsDigestType               SourceDigestResult;
    ///digest length
    TFfexDsIntType                  SourceDigestResultLen;
    ///digest type
    TFfexDsEncryptType              SourceDigestType;
    ///encrypted length
    TFfexDsIntType                  SourcePubKeyEncryptResultLen;
    ///encrypted result(using user public key to encrypt source public key)
    TFfexDsPublicEncSourceResultType  SourcePubKeyEncryptResult;

};

struct CWindowsLocalSysInfo {
    ///terminal type
    TFfexDsTerminalType                 TerminalType;
    ///info get time
    TFfexDsInfoAcquireTimeType          InfoAcquireTime;
    ///private ip address 1
    TFfexDsIPAddress                    LocalNetIP1;
    ///private ip address 2
    TFfexDsIPAddress                    LocalNetIP2;
    ///mac address 1
    TFfexDsMACAddress                   NetworkCardMACAddress1;
    ///mac address 2
    TFfexDsMACAddress                   NetworkCardMACAddress2;
    ///device name
    TFfexDsDeviceName                   DeviceName;
    ///operation system
    TFfexDsOSVersion                    OSVersion;
    ///hard disk serial number
    TFfexDsHarddiskSerialNumber         HarddiskSerialNumber;
    ///CPU serial number
    TFfexDsCPUSerialNumber              CPUSerialNumber;
    ///BIOS serial number
    TFfexDsBIOSSerialNumber             BIOSSerialNumber;
    ///system disk partition info
    TFfexDsSystemDiskPartitionInfo      SystemDiskPartitionInfo;
    ///exception flag
    TFfexDsExceptionFlagType            ExceptionFlag;   
};

struct CLinuxLocalSysInfo {
    ///terminal type
    TFfexDsTerminalType                 TerminalType;
    ///info get time
    TFfexDsInfoAcquireTimeType          InfoAcquireTime;
    ///private IP address 1
    TFfexDsIPAddress                    LocalNetIP1;
    ///private IP address 1   
    TFfexDsIPAddress                    LocalNetIP2;
    ///mac address 1
    TFfexDsMACAddress                   NetworkCardMACAddress1;
    ///mac address 2
    TFfexDsMACAddress                   NetworkCardMACAddress2;
    ///device name
    TFfexDsDeviceName                   DeviceName;
    ///operation system version
    TFfexDsOSVersion                    OSVersion;
    ///hard disk serial number
    TFfexDsHarddiskSerialNumber         HarddiskSerialNumber;
    ///CPU serial number
    TFfexDsCPUSerialNumber              CPUSerialNumber;
    ///BIOS serial number
    TFfexDsBIOSSerialNumber             BIOSSerialNumber;
    ///exception flag
    TFfexDsExceptionFlagType            ExceptionFlag; 

};

struct CMacOsLocalSysInfo {
    ///terminal type
    TFfexDsTerminalType                 TerminalType;
    ///info get time
    TFfexDsInfoAcquireTimeType          InfoAcquireTime;
    ///private IP address 1
    TFfexDsIPAddress                    LocalNetIP1;
    ///private IP address 2
    TFfexDsIPAddress                    LocalNetIP2;
    ///mac address 1
    TFfexDsMACAddress                   NetworkCardMACAddress1;
    ///mac address 2
    TFfexDsMACAddress                   NetworkCardMACAddress2;
    ///device name
    TFfexDsDeviceName                   DeviceName;
    ///operation system version
    TFfexDsOSVersion                    OSVersion;
    ///hard disk serial number
    TFfexDsHarddiskSerialNumber         HarddiskSerialNumber;
    ///device serial number
    TFfexDsDeviceSerialNumber           DeviceSerialNumber;           
    ///exception flag
    TFfexDsExceptionFlagType            ExceptionFlag;
};

struct CAndriodLocalSysInfo {
    ///terminal type - DS_TERMINAL_TYPE
    TFfexDsTerminalType                 TerminalType;
    ///info get time
    TFfexDsInfoAcquireTimeType          InfoAcquireTime;
    ///terminal ip address
    TFfexDsIPAddress                    MobileTerminalIP;
    ///gps info
    TFfexDsGPSInfo                      GpsInfo;
    ///operation system version
    TFfexDsOSVersion                    OSVersion;
    ///device name
    TFfexDsDeviceName                   DeviceName;
    ///device type
    TFfexDsDeviceType                   DeviceType;
    ///IMEI1
    TFfexDsIMEI                         IMEI1;
    ///IMEI2
    TFfexDsIMEI                         IMEI2;
    ///MEID
    TFfexDsMEID                         MEID;
    ///MAC address
    TFfexDsMACAddress                   DeviceMACAddress;
    ///phone number
    TFfexDsMobilephoneNumber            MobilephoneNumber;    
    ///device serial number
    TFfexDsDeviceSerialNumber           DeviceSerialNumber; 
    ///IMSI
    TFfexDsIMSI                         IMSI;
    ///ICCID of IC card
    TFfexDsICCID                        ICCID;
    ///exception flag
    TFfexDsExceptionFlagType            ExceptionFlag;   
};

struct CIOSLocalSysInfo {
    ///terminal type
    TFfexDsTerminalType                 TerminalType;
    ///info get time
    TFfexDsInfoAcquireTimeType          InfoAcquireTime;
    ///terminal ip address
    TFfexDsIPAddress                    MobileTerminalIP;
    ///gps info
    TFfexDsGPSInfo                      GpsInfo;
    ///operation system version
    TFfexDsOSVersion                    OSVersion;
    ///device name
    TFfexDsDeviceName                   DeviceName;
    ///device type
    TFfexDsDeviceType                   DeviceType;
    ///network operator
    TFfexDsNetworkOperator              NetworkOperator;
    ///UUID
    TFfexDsUUID                         UUID;
    ///exception flag
    TFfexDsExceptionFlagType            ExceptionFlag;    
};

struct COfflineInfo{
    ///terminal type
    TFfexDsTerminalType                 TerminalType;
    ///info get time
    TFfexDsInfoAcquireTimeType          InfoAcquireTime;
    ///Phone Number
    TFfexDsPhoneNumber                  PhoneNumber;
    ///client deposit
    TFfexDsClientInternalCapitalAccount ClientInternalCapitalAcc;
    ///client type
    TFfexDsUserType                     UserType;
};


///additional info supply by proxy
struct CProxyAdditionalInfo {
    ///exception
    //TFfexDsExceptionFlagType            ExceptionFlag;
    ///AppID
    //TFfexDsInfoAcquireAppIDType         AppID;
    ///client public IP
    TFfexDsIPAddress                    ClientTradingTreminalPubNetIP;
    ///client public port
    TFfexDsPortNumber                   ClientTradingTreminalPubNetPort;
    ///client login time
    TFfexDsLoginTimeType                ClientTradingTreminalLoginTime;
};

///additonal info supply by front
struct CFrontAdditionalInfo {
    ///exception flag
    TFfexDsExceptionFlagType            ExceptionFlag;  
    ///RelayAppID
    TFfexDsInfoAcquireAppIDType         RelayAppID;
    ///AppID
    TFfexDsInfoAcquireAppIDType         AppID;
    ///client public IP
    TFfexDsIPAddress                    ClientTradingTreminalPubNetIP;
    ///client public port
    TFfexDsPortNumber                   ClientTradingTreminalPubNetPort;
    ///client login time
    TFfexDsLoginTimeType                ClientTradingTreminalLoginTime;    
    ///proxy IP
    TFfexDsIPAddress                    ProxyPubNetIP;
    ///proxy port
    TFfexDsPortNumber                   ProxyPubNetPort;
    ///proxy login time
    TFfexDsLoginTimeType                ProxyLoginTime;   
};

///additional info supply by kernel
struct CKernelAdditionalInfo {
    ///trading software vendor ID
    TFfexDsTradeSoftwareVendorIDType    TradeSoftwareVendorID;    
    ///public key version
    TFfexDsEncKeyVersionType            EncKeyVersion;
    ///client deposit
    TFfexDsClientInternalCapitalAccount ClientInternalCapitalAcc;
    ///client type
    TFfexDsUserType                     UserType;
};

///additonal info supply
struct CTotalAdditionalInfo {
    TFfexDsBoolType         HasProxyAddInfo;
    CProxyAdditionalInfo    ProxyAddInfo;
    CFrontAdditionalInfo    FrontAddInfo;
    CKernelAdditionalInfo   KernelAddInfo;
};

///final encrypted terminal info
struct CUserTerminalEncryptedInfo {
    TFfexDsIntType                      DataLen;
    TFfexDsUserTerminalEncryptedType    EncryptedData;
};

struct CKeyInfo{
    TFfexDsEncryptType              EncryptType;
    TFfexDsPublicKeyVersionType     SourcePubKeyVersion;
    TFfexDsExceptionFlagType        ExceptionFlag;
};


}

#endif
