/**
 * CFFEX Confidential.
 *
 * @Copyright 2018 CFFEX.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the China Copyright Office.
 *
 * Date:   2018-11-12
 */

#ifndef __DS_DEEP_SUPERVISE_USER_API_H__
#define __DS_DEEP_SUPERVISE_USER_API_H__

#include <stdio.h>
#include <stdlib.h>
#include "DeepSuperviseDataStruct.h"


#if defined(USERAPI_IS_LIB) && defined(WINDOWS)
#ifdef LIB_USER_API_EXPORT
#define USER_API_EXPORT __declspec(dllexport)
#else
#define USER_API_EXPORT __declspec(dllimport)
#endif
#else
#define USER_API_EXPORT 
#endif

namespace cffex_deep_supervise {

class USER_API_EXPORT CDeepSuperviseUserApi {

public:

    /**
     * create an instance
     */
    static CDeepSuperviseUserApi *CreateDeepSuperviseUserApi();

    // ============================= app/API terminal used ====================================//

    /**
     * prepare user certificate. The response info will be sent to front
     * @param   pUserInfo           user info
     * @param   pUserCertInfo       output buffer
     * @param   nOutBufLen          output buffer len
     * @param   nOutUsedLen         output result len 
     * @return   0  success
     *          -1  input param error
     *          -2  output buffer is too small
     * @remark  the struct of output is CUserCertificateSoRspField
     *
     */
    virtual int PrepareUserCertificate(DS_IN CUserCertificateField *pUserInfo, DS_OUT char *pUserCertInfo, DS_IN int nOutBufLen, DS_OUT int &nOutUsedLen) = 0;

    /**
     * register the response info from front
     * @param pUserCertFrontRspInfo response info
     * @return  0 success
     *         -1 failed
     * @remark the struct of input is CUserCertificateFrontRspField
     */
    virtual int RegisterRspUserCertificate(DS_IN const         char* pUserCertFrontRspInfo) = 0;

    
    /**
     * get user local system info. the output is an encrypted and formated data
     * @param pOutBuf       output buffer
     * @param nOUtBufLen    output buffer len
     * @param nOutUsedLen   output result len     
     * @return           0  get info success
     *                  -1  output buffer is too small
     *                  -2  get info failed
     */
    virtual int GetUserLocalSystemInfo(char *pOutBuf, int nOutBufLen, int &nOutUsedLen, char &outExceptionFlag) = 0;

        /**
     * register information and get user local system info. the output is an encrypted and formated data
     * @param pOutBuf       output buffer
     * @param nOUtBufLen    output buffer len
     * @param nOutUsedLen   output result len     
     * @return           0  get info success
     *                  -1  output buffer is too small
     *                  -2  get info failed
     */
    virtual int StaticGetUserLocalSystemInfo(char *pOutBuf, int nOutBufLen, int &nOutUsedLen, char &outExceptionFlag) = 0;

};


}


#endif

