/**
 * CFFEX Confidential.
 *
 * @Copyright 2018 CFFEX.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the China Copyright Office.
 *
 * Date:   2018-11-20
 */

#ifndef __DS_DEEP_SUPERVISE_USER_API_H__
#define __DS_DEEP_SUPERVISE_USER_API_H__

#import <CoreLocation/CLLocationManagerDelegate.h>

/**
 加密类型
 */
typedef enum {
    DS_ENCRYPT_TYPE_RSA_PKCS1_PADDING        = '1',
    DS_ENCRYPT_TYPE_RSA_PKCS1_OAEP_PADDING   = '2',
    DS_ENCRYPT_TYPE_RSA_SSLV23_PADDING       = '3',
    DS_ENCRYPT_TYPE_RSA_NO_PADDING           = '4',
    DS_ENCRYPT_TYPE_SM2                      = '5',
    DS_ENCRYPT_TYPE_MD5                      = '6',
    DS_ENCRYPT_TYPE_SM3                      = '7'
} DS_ENCRYPT_TYPES;

@protocol DeepSuperviseUserApiDelegate;

@interface DeepSuperviseUserApi : NSObject<CLLocationManagerDelegate>

+(instancetype _Nonnull )sharedInstance;

@property(assign, nonatomic, nullable) id<DeepSuperviseUserApiDelegate> delegate;

/**
 准备客户认证数据
 @param appId 应用ID
 @param pwd 密码
 @param type 加密类型DS_ENCRYPT_TYPES
 */
-(void)cffexit_prepareCertificate:(const char*_Nonnull)appId
                         password:(const char*_Nonnull)pwd
                             type:(DS_ENCRYPT_TYPES)type;

/**
 模拟服务器端验证（仅供测试）
 @param appId 应用ID
 @param pwd 密码
 @param type 加密类型 参见：EncryptType
 @param ver 公钥版本
 @param cert 本地凭证
 @return 服务端凭证
 */
-(const char*_Nullable)checkCertificate:(const char*_Nonnull)appId
                               password:(const char*_Nonnull)pwd
                                   type:(DS_ENCRYPT_TYPES)type
                                version:(const char*_Nonnull)ver
                                   cert:(const char*_Nonnull)cert;

/**
 注册认证信息
 @param certificate 认证信息，上一步block中cert参数
 @return 0注册成功/-1注册失败
 */
-(int)cffexit_registerCertificate:(const char*_Nonnull)certificate;

/**
 开始获取加密后本地系统信息
 */
-(void)cffexit_systemInfo;

/**
 使用固定公钥获取加密后本地系统信息
 */
-(void)cffexit_staticSystemInfo;

@end

#endif /* __DS_DEEP_SUPERVISE_USER_API_H__ */
